#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 texmath
version:              0.13.2.1
visibility:           public
id:                   texmath-0.13.2.1-8dtp39V1Vf6K9D0qAimy7M
key:                  texmath-0.13.2.1-8dtp39V1Vf6K9D0qAimy7M
license:              GPL-2.0-only
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Matthew Pickering
stability:            Experimental
homepage:             http://github.com/jgm/texmath
synopsis:             Conversion between math formats.
description:
    The texmath library provides functions to read
    and write TeX math, presentation MathML, and OMML (Office Math
    Markup Language, used in Microsoft Office). Support is also
    included for converting math formats to Gnu eqn, typst,
    StarMath, and pandoc'\''s native format (allowing conversion, via
    pandoc, to a variety of different markup formats). The TeX
    reader supports basic LaTeX and AMS extensions, and it can
    parse and apply LaTeX macros. (See
    <https://johnmacfarlane.net/texmath here> for a live demo of
    bidirectional conversion between LaTeX and MathML.)

    The package also includes several utility modules which may be
    useful for anyone looking to manipulate either TeX math or
    MathML.  For example, a copy of the MathML operator dictionary is
    included.

    Use the @executable@ flag to install a standalone
    executable, @texmath@, that converts formulas from one
    format to another. (Use the @--help@ flag for a description of all
    functionality).

    Use the @server@ flag to install a web server, @texmath-server@,
    that exposes a JSON API allowing conversion of individual
    formulas and batches of formulas.

category:             Text
abi:                  bf2a80b2859d552e7a7376b2b1fa9e5a
exposed:              True
exposed-modules:
    Text.TeXMath Text.TeXMath.Readers.MathML
    Text.TeXMath.Readers.MathML.EntityMap
    Text.TeXMath.Readers.MathML.MMLDict Text.TeXMath.Readers.OMML
    Text.TeXMath.Readers.TeX Text.TeXMath.Readers.TeX.Macros
    Text.TeXMath.Shared Text.TeXMath.TeX Text.TeXMath.Types
    Text.TeXMath.Unicode.Fonts Text.TeXMath.Unicode.ToTeX
    Text.TeXMath.Unicode.ToUnicode Text.TeXMath.Writers.Eqn
    Text.TeXMath.Writers.MathML Text.TeXMath.Writers.OMML
    Text.TeXMath.Writers.Pandoc Text.TeXMath.Writers.StarMath
    Text.TeXMath.Writers.TeX Text.TeXMath.Writers.Typst

hidden-modules:       Text.TeXMath.Readers.TeX.Commands Paths_texmath
import-dirs:          /usr/lib/ghc-9.6.6/site-local/texmath-0.13.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/texmath-0.13.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/texmath-0.13.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.6.6/texmath-0.13.2.1
hs-libraries:         HStexmath-0.13.2.1-8dtp39V1Vf6K9D0qAimy7M
depends:
    base-4.18.2.1 containers-0.6.7 mtl-2.3.1
    pandoc-types-1.23.1.2-7r04FP2c39lATDnNYvBdb6 parsec-3.1.16.1
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl syb-0.7.4-CWkOfF6Y0mt62kPybHOEB1
    text-2.0.2 typst-symbols-0.3-4dNsmXLN7eG8YIKTGZO3LG
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt

haddock-interfaces:   /usr/share/doc/haskell-texmath/html/texmath.haddock
haddock-html:         /usr/share/doc/haskell-texmath/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

